package javax.swing;

import java.util.Enumeration;
import java.util.Vector;
import java.io.Serializable;

public class ButtonGroup implements Serializable
{
    protected Vector<AbstractButton> buttons;
    ButtonModel selection;
    
    public ButtonGroup() {
        this.buttons = new Vector();
        this.selection = null;
    }
    
    public void add(AbstractButton obj) {
        if (obj == null) {
            return;
        }
        this.buttons.addElement(obj);
        if (obj.isSelected()) {
            if (this.selection == null) {
                this.selection = obj.getModel();
            }
            else {
                obj.setSelected(false);
            }
        }
        obj.getModel().setGroup(this);
        return;
    }
    
    public void remove(AbstractButton obj) {
        if (obj == null) {
            return;
        }
        this.buttons.removeElement(obj);
        if (obj.getModel() == this.selection) {
            this.selection = null;
        }
        obj.getModel().setGroup(null);
        return;
    }
    
    public void clearSelection() {
        if (this.selection != null) {
            ButtonModel selection = this.selection;
            this.selection = null;
            selection.setSelected(false);
        }
    }
    
    public Enumeration<AbstractButton> getElements() {
        return this.buttons.elements();
    }
    
    public ButtonModel getSelection() {
        return this.selection;
    }
    
    public void setSelected(ButtonModel selection, boolean b) {
        if (b && selection != null && selection != this.selection) {
            ButtonModel selection2 = this.selection;
            this.selection = selection;
            if (selection2 != null) {
                selection2.setSelected(false);
            }
            selection.setSelected(true);
        }
    }
    
    public boolean isSelected(ButtonModel buttonModel) {
        return buttonModel == this.selection;
    }
    
    public int getButtonCount() {
        if (this.buttons == null) {
            return 0;
        }
        return this.buttons.size();
    }
}
